/**
 * This file demonstrates the ability to command a group with an io module.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/lookup_helpers.c"
#include "util/hebi_util.h"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  int numModules = hebiGroupGetSize(group);

  // Create a command object; this can be sent to the group
  HebiGroupCommandPtr command = hebiGroupCommandCreate(numModules);
  if (command == NULL)
  {
    printf("Could not create command object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // Use command send with acknowledgement to alternate pin "E2"
  float period = 1.0f;
  long timeout_ms = 100;
  int i;
  for (i = 0; i <= 10; ++i)
  {
    int module_index;
    for (module_index = 0; module_index < numModules; module_index++)
    {
      // We get the command for this particular module
      HebiCommandPtr module_cmd = hebiGroupCommandGetModuleCommand(command, module_index);
      // Turn this io pin e2 off and on, alternating
      int64_t val = i % 2;
      hebiCommandSetIoPinInt(module_cmd, HebiCommandIoBankE, 2, &val);
    }

    if (hebiGroupSendCommandWithAcknowledgement(group, command, timeout_ms) == 0)
    {
      printf("Got acknowledgement.\n");
    }
    else
    {
      printf("Did not receive acknowledgement!\n");
    }
    hebi_sleep_ms(period * 1000);
  }

  // We must release the resources back to the library when done!
  hebiGroupCommandRelease(command);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
