/**
 * This file demonstrates the ability to command a group.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/lookup_helpers.c"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    printf("Could not find group!\n");
    hebiCleanup();
    return -1;
  }

  int numModules = hebiGroupGetSize(group);

  // Create a command object; this can be sent to the group
  HebiGroupInfoPtr info = hebiGroupInfoCreate(numModules);
  if (info == NULL)
  {
    printf("Could not create command object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  int res = hebiGroupRequestInfo(group, info, 4000);
  if (res != 0)
  {
    hebiGroupInfoRelease(info);
    printf("Could not get info from group!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }
  
  res = hebiGroupInfoWriteGains(info, "my_gains.xml");
  if (res != 0)
    printf("Could not export gains object!\n");

  // We must release the resources back to the library when done!
  hebiGroupInfoRelease(info);
  hebiGroupRelease(group);
  hebiCleanup();
  return res == 0 ? 0 : -1;
}
