/**
 * This file demonstrates the ability to command a group.
 */

#include <stdio.h>
#include <stdlib.h>

#include "hebi.h"

int main(int argc, char* argv[])
{
  if (argc != 2)
  {
    printf("Usage: ./gains_import_example <number of modules>");
    hebiCleanup();
    return -1;
  }

  // Create a command object; this can be sent to the group
  HebiGroupCommandPtr command = hebiGroupCommandCreate(atoi(argv[1]));
  if (command == NULL)
  {
    printf("Could not create command object!\n");
    hebiCleanup();
    return -1;
  }

  int res = hebiGroupCommandReadGains(command, "my_gains.xml");
  if (res != 0)
  {
    printf("Could not import gains object!\n");
    hebiGroupCommandRelease(command);
    hebiCleanup();
    return -1;
  }

  // Re-export the gains  
  hebiGroupCommandWriteGains(command, "my_gains_export.xml");

  // We must release the resources back to the library when done!
  hebiGroupCommandRelease(command);
  hebiCleanup();
  return res == 0 ? 0 : -1;
}
