/**
 * This demonstrates a scripted approach at parsing information from a set of
 * log files.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/lookup_helpers.c"
#include "util/hebi_util.h"

int main(int argc, char* argv[])
{
  // We read each name passed in in the argument list, and attempt to open and
  // parse a log file with that name:
  int file_idx;
  for (file_idx = 1; file_idx < argc; ++file_idx)
  {
    HebiLogFilePtr log = hebiLogFileOpen(argv[file_idx]);
    if (log == NULL)
    {
      printf("Could not open file: %s\n", argv[file_idx]);
      continue;
    }

    printf("Reading file: %s\n", argv[file_idx]);    

    int num_modules = hebiLogFileGetNumberOfModules(log);
    HebiGroupFeedbackPtr group_fbk = hebiGroupFeedbackCreate(num_modules);
    if (hebiLogFileGetNextFeedback(log, group_fbk) == HebiStatusSuccess)
    {
      int module_idx = 0;
      for (module_idx = 0; module_idx < num_modules; ++module_idx)
      {
        HebiFeedbackPtr fbk = hebiGroupFeedbackGetModuleFeedback(group_fbk, module_idx);
        uint64_t id;
        if (hebiFeedbackGetUInt64(fbk, HebiFeedbackUInt64SenderId, &id) == HebiStatusSuccess)
        {
          uint8_t* id8 = (uint8_t*)&id;
          printf("module %d: ", module_idx);
          printf("%02x:%02x:%02x:%02x:%02x:%02x\n", id8[5], id8[4], id8[3], id8[2], id8[1], id8[0]);
        }
      }
    }
    else
    {
      printf("Could not read feedback from %s", argv[file_idx]);
    }
    hebiGroupFeedbackRelease(group_fbk);
    hebiLogFileRelease(log);
  }

  hebiCleanup();
  return 0;
}
