/**
 * Helper functions to print out module/group feedback
 */

#include <stdio.h>
#include <inttypes.h>

#include "hebi.h"

void print_module_feedback(HebiFeedbackPtr feedback)
{
  // The feedback object contains many fields and subobjects, depending on
  // the type of feedback. Here we get a subcommand of this object which
  // contains relevant feedback for actuators, such as position, velocity,
  // and effort:
  int64_t revs; float offset;
  float velocity, effort;
  hebiFeedbackGetHighResAngle(feedback, HebiFeedbackHighResAnglePosition, &revs, &offset);
  hebiFeedbackGetFloat(feedback, HebiFeedbackFloatVelocity, &velocity);
  hebiFeedbackGetFloat(feedback, HebiFeedbackFloatEffort, &effort);

  printf("Position %" PRId64 " + %f | Velocity %f | Effort %f\n",
    revs, offset, velocity, effort 
  );
}

void print_group_feedback(HebiGroupFeedbackPtr group_feedback)
{
  int num_modules = hebiGroupFeedbackGetSize(group_feedback);
  int mod_idx;
  for (mod_idx = 0; mod_idx < num_modules; mod_idx++)
  {
    printf("Module index: %d\n", mod_idx);
    HebiFeedbackPtr module_feedback =
      hebiGroupFeedbackGetModuleFeedback(group_feedback, mod_idx);
    print_module_feedback(module_feedback);
  }
}
